import { HttpClient, HttpHeaders } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { Observable } from 'rxjs';
import { catchError } from 'rxjs/operators';

import { ErrorLoggerService } from '../core/error-logger.service';
import { SaleCategory } from '../core/sale-category';

const httpOptions = {
  headers: new HttpHeaders({ 'Content-Type': 'application/json' }),
};
const url = '/api/sale-categories';
const serviceName = 'SaleCategoryService';

@Injectable({
  providedIn: 'root',
})
export class SaleCategoryService {
  constructor(private http: HttpClient, private log: ErrorLoggerService) {}

  get(id: string | null): Observable<SaleCategory> {
    const getUrl: string = id === null ? url : `${url}/${id}`;
    return this.http
      .get<SaleCategory>(getUrl)
      .pipe(
        catchError(this.log.handleError(serviceName, `get id=${id}`)),
      ) as Observable<SaleCategory>;
  }

  list(): Observable<SaleCategory[]> {
    return this.http
      .get<SaleCategory[]>(`${url}/list`)
      .pipe(catchError(this.log.handleError(serviceName, 'list'))) as Observable<SaleCategory[]>;
  }

  save(saleCategory: SaleCategory): Observable<SaleCategory> {
    return this.http
      .post<SaleCategory>(url, saleCategory, httpOptions)
      .pipe(catchError(this.log.handleError(serviceName, 'save'))) as Observable<SaleCategory>;
  }

  update(saleCategory: SaleCategory): Observable<SaleCategory> {
    return this.http
      .put<SaleCategory>(`${url}/${saleCategory.id}`, saleCategory, httpOptions)
      .pipe(catchError(this.log.handleError(serviceName, 'update'))) as Observable<SaleCategory>;
  }

  saveOrUpdate(saleCategory: SaleCategory): Observable<SaleCategory> {
    if (!saleCategory.id) {
      return this.save(saleCategory);
    }
    return this.update(saleCategory);
  }

  delete(id: string): Observable<SaleCategory> {
    return this.http
      .delete<SaleCategory>(`${url}/${id}`, httpOptions)
      .pipe(catchError(this.log.handleError(serviceName, 'delete'))) as Observable<SaleCategory>;
  }
}
