import { Component, Inject } from '@angular/core';
import { FormArray, FormBuilder, FormControl, FormGroup, Validators } from '@angular/forms';
import { MAT_DIALOG_DATA, MatDialogRef } from '@angular/material/dialog';
import { round } from 'mathjs';
import { Observable } from 'rxjs';

import { DiscountDataSource } from './discount-datasource';
import { DiscountItem } from './discount-item';

@Component({
  selector: 'app-modifiers',
  templateUrl: './discount.component.html',
  styleUrls: ['./discount.component.css'],
})
export class DiscountComponent {
  list: DiscountItem[] = [];
  form: FormGroup;
  dataSource: DiscountDataSource = new DiscountDataSource([]);

  displayedColumns = ['name', 'discount'];

  constructor(
    public dialogRef: MatDialogRef<DiscountComponent>,
    private fb: FormBuilder,
    @Inject(MAT_DIALOG_DATA)
    public data: Observable<DiscountItem[]>,
  ) {
    this.form = this.fb.group({
      discounts: '',
    });
    this.data.subscribe((list: DiscountItem[]) => {
      this.list = list;
      this.form.setControl(
        'discounts',
        this.fb.array(
          this.list.map((x) =>
            this.fb.group({
              name: [x.name],
              discount: [
                '' + (x.discount !== 0 ? x.discount * 100 : ''),
                [Validators.min(0), Validators.max(x.discountLimit * 100)],
              ],
            }),
          ),
        ),
      );
      this.dataSource = new DiscountDataSource(this.list);
    });
  }

  accept(): void {
    const array = this.form.get('discounts') as FormArray;
    for (let i = this.list.length - 1; i >= 0; i--) {
      const item = this.list[i];
      const control = (array.controls[i] as FormGroup).controls.discount as FormControl;
      if (
        control.value === null ||
        control.value === '' ||
        (control.pristine && control.value === '0')
      ) {
        this.list.splice(i, 1);
      } else {
        item.discount = Math.max(Math.min(round(control.value / 100, 5), item.discountLimit), 0);
      }
    }
    this.dialogRef.close(this.list);
  }
}
