import { CommonModule } from '@angular/common';
import { NgModule } from '@angular/core';
import { RouterModule, Routes } from '@angular/router';

import { AuthGuard } from '../auth/auth-guard.service';
import { MenuCategoryListResolver } from '../menu-category/menu-category-list-resolver.service';
import { SaleCategoryListResolver } from '../sale-category/sale-category-list-resolver.service';

import { TemporalProductDetailComponent } from './temporal-product-detail/temporal-product-detail.component';
import { TemporalProductListResolverService } from './temporal-product-list-resolver.service';
import { TemporalProductListComponent } from './temporal-product-list/temporal-product-list.component';
import { TemporalProductResolverService } from './temporal-product-resolver.service';

const temporalProductsRoutes: Routes = [
  {
    path: '',
    component: TemporalProductListComponent,
    canActivate: [AuthGuard],
    data: {
      permission: 'Temporal Products',
    },
    resolve: {
      list: TemporalProductListResolverService,
      menuCategories: MenuCategoryListResolver,
      saleCategories: SaleCategoryListResolver,
    },
  },
  {
    path: 'new',
    component: TemporalProductDetailComponent,
    canActivate: [AuthGuard],
    data: {
      permission: 'Temporal Products',
    },
    resolve: {
      item: TemporalProductResolverService,
      menuCategories: MenuCategoryListResolver,
      saleCategories: SaleCategoryListResolver,
    },
  },
  {
    path: ':id',
    component: TemporalProductDetailComponent,
    canActivate: [AuthGuard],
    data: {
      permission: 'Temporal Products',
    },
    resolve: {
      item: TemporalProductResolverService,
      menuCategories: MenuCategoryListResolver,
      saleCategories: SaleCategoryListResolver,
    },
  },
];

@NgModule({
  imports: [CommonModule, RouterModule.forChild(temporalProductsRoutes)],
  exports: [RouterModule],
  providers: [TemporalProductListResolverService, TemporalProductResolverService],
})
export class TemporalProductsRoutingModule {}
