import { HttpClient, HttpParams } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { Observable } from 'rxjs';
import { catchError } from 'rxjs/operators';

import { ErrorLoggerService } from '../core/error-logger.service';
import { Product } from '../core/product';

import { UpdateProductPrices } from './update-product-prices';

const url = '/api/update-product-prices';
const serviceName = 'UpdateProductPricesService';

@Injectable({
  providedIn: 'root',
})
export class UpdateProductPricesService {
  constructor(private http: HttpClient, private log: ErrorLoggerService) {}

  get(id: string | null, date: string | null): Observable<UpdateProductPrices> {
    const getUrl: string = id === null ? url : `${url}/${id}`;
    const options = { params: new HttpParams() };
    if (date !== null) {
      options.params = options.params.set('d', date);
    }
    return this.http
      .get<UpdateProductPrices>(getUrl, options)
      .pipe(
        catchError(this.log.handleError(serviceName, 'get')),
      ) as Observable<UpdateProductPrices>;
  }

  save(item: UpdateProductPrices): Observable<UpdateProductPrices> {
    const saveUrl: string = item.menuCategoryId === null ? url : `${url}/${item.menuCategoryId}`;
    return this.http
      .post<Product[]>(saveUrl, item)
      .pipe(
        catchError(this.log.handleError(serviceName, 'save')),
      ) as Observable<UpdateProductPrices>;
  }
}
